@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-    Copyright 2007 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License or ( at
-   your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-   act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include <kservice.h>
@@ -161,8 +148,8 @@ private Q_SLOTS:
         // Check what's in QMimeDatabase
         QStringList newPatterns = db.mimeTypeForName(QStringLiteral("text/plain")).globPatterns();
         newPatterns.sort();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) // adjust to 5.15 if the fix gets backported
-        QEXPECT_FAIL("", "QTBUG-85436 is only fixed in Qt 6.0", Continue);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 2)
+        QEXPECT_FAIL("", "QTBUG-85436 is only fixed in Qt 5.15.2", Continue);
 #endif
         QCOMPARE(newPatterns, patterns);
         if (newPatterns == patterns) { // TODO Qt6: remove the if (keep the QVERIFY!)
